/**
 * Copyright (C) 2011 - 101loops.com <dev@101loops.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.crashnote.servlet.collect;

import com.crashnote.core.collect.BaseCollector;
import com.crashnote.core.config.IConfigChangeListener;
import com.crashnote.core.model.data.DataObject;
import com.crashnote.servlet.config.ServletConfig;

import javax.servlet.http.*;
import java.util.*;

/**
 * Collector to transform a HTTP session into a structured data format.
 */
public class SessionCollector
    extends BaseCollector<ServletConfig> implements IConfigChangeListener<ServletConfig> {

    protected boolean skipSessionData;

    // SETUP ======================================================================================

    public SessionCollector(final ServletConfig config) {
        super(config);
        updateConfig(config);
    }

    public void updateConfig(final ServletConfig config) {
        config.addListener(this);
        this.skipSessionData = config.getSkipSessionData();
    }

    // INTERFACE ==================================================================================

    public DataObject collect(final HttpServletRequest req) {
        final DataObject data = createDataObj();
        {
            final HttpSession session = req.getSession();

            // collect basic info
            data.put("id", session.getId());
            data.put("started", session.getCreationTime());

            // collect session data
            if (!skipSessionData) {
                final DataObject content = createDataObj();
                {
                    final Enumeration names = session.getAttributeNames();
                    while (names.hasMoreElements()) {
                        final String name = names.nextElement().toString();
                        final String value = session.getAttribute(name).toString();
                        content.put(name, value);
                    }
                }
                data.putObj("data", content);
            }
        }
        return data;
    }

}
